@@ -167,7 +167,7 @@ Requirements:
         Args:
             force_refresh (bool): Whether to force refresh the cache
 
-        Returns:
+        Returns
             list: List of tool dictionaries with names and descriptions
         """
         current_time = datetime.now()
@@ -220,7 +220,7 @@ Requirements:
             query (str): User query
             max_tools (int): Maximum number of tools to send to LLM
 
-        Returns:
+        Returns
             list: Filtered list of tools
         """
         if len(available_tools) <= max_tools:
@@ -269,7 +269,7 @@ Requirements:
         Args:
             tools (list): List of tool dictionaries
 
-        Returns:
+        Returns
             str: Compact formatted tool descriptions for the prompt
         """
         formatted_tools = []
@@ -296,7 +296,7 @@ Requirements:
             include_reasoning (bool): Whether to include selection reasoning
             categories (list, optional): List of tool categories to filter by
 
-        Returns:
+        Returns
             dict: Dictionary containing selected tools and metadata
         """
         try:
@@ -452,7 +452,7 @@ Requirements:
             categories (list, optional): List of tool categories to filter by. Applied before LLM selection.
             return_list_only (bool, optional): If True, returns only a list of tool specifications. Overrides other return options.
 
-        Returns:
+        Returns
             str, tuple, or list:
                 - If return_list_only is True: List of tool specifications
                 - If return_call_result is False: Tool prompts as a formatted string
@@ -532,7 +532,7 @@ Requirements:
             categories: Requested categories filter
             return_call_result: Whether return_call_result was True
 
-        Returns:
+        Returns
             str: JSON formatted search results
         """
         import json
